#!/bin/sh

# Copyright (C) 2011 Igalia, S.L.
# Author: Alejo Pacín Jul <apacin@igalia.com>

# Note: to use sysprof, you must run it as root.

# Installation path.
IPATH='/opt/gnome'
# Wait time between commands.
WTIME=5
# Accessibility scripts path.
ASPATH='../a11y-scripts'
# Output files path.
OPATH='Output'

if test $# -ne 5
then
  echo -n 'sysprof.sh <true|false> <true|false> <output_file> <application> <sleep_time> \n'; exit
fi

# $1 = boolean indicating whether to enable or disable the accessibility
# $2 = boolean indicating whether to launch Orca.
case $1 in
  true)
    export GTK_MODULES=atk-bridge
    sh $ASPATH/gsettings/enable_accessibility.sh
    $IPATH/libexec/at-spi-bus-launcher &
    sleep $WTIME
    $IPATH/libexec/at-spi2-registryd &
    sleep $WTIME
    if $2
    then
      orca --replace &
      sleep $WTIME
    fi;;
  false)
    killall $IPATH/libexec/at-spi-bus-launcher
    killall $IPATH/libexec/at-spi2-registryd
    sh $ASPATH/gsettings/disable_accessibility.sh
    export GTK_MODULES=canberra-gtk-module:canberra-gtk-module;;
  *) echo -n 'sysprof.sh <true|false> <true|false> <output_file> <application> <sleep_time> \n'; exit;;
esac

# It checks if the previous action has been applied.
if test $1 != `sh $ASPATH/gsettings/get_accessibility.sh`
then
  echo -n 'Error: accesibility is working bad \n'; exit
fi

# $3 = output file.
OFILE="$OPATH/$3.sp"
sudo sysprof-cli $OFILE &

# $4 = application to test.
$4 &
APP=`echo "$4" | cut -f 1 -d ' '`

# $5 = Wait time (sec) set equal for all tests to can compare between them.
STIME=$5

# If accessibility is enable, it checks if the tested application is registered.
# if test $1 = true
# then
#   sleep $WTIME
#   STIME=`expr $STIME - $WTIME`
#   if ! test `python $ASPATH/show_apps.py | grep $APP`
#   then
#     echo -n 'Error: application is not registered \n'
#     killall $APP; exit
#   fi
# fi

sleep $STIME

# Stop sysprof monitoring.
sudo killall sysprof-cli
sleep $WTIME
while ! test -e $OFILE
do
  echo -n 'Waiting... \n'
  sleep $WTIME
done
echo -n "Output file generated: $OFILE \n"

# Stop tested application.
killall $APP

# If necessary, stop Orca.
if $2
then
  killall orca
  sleep $WTIME
fi

# In any case, finally, accesibility must be disable.
killall $IPATH/libexec/at-spi-bus-launcher
killall $IPATH/libexec/at-spi2-registryd
sh $ASPATH/gsettings/disable_accessibility.sh
export GTK_MODULES=canberra-gtk-module:canberra-gtk-module
