#!/bin/sh

# Copyright (C) 2011 Igalia, S.L.
# Author: Alejo Pacín Jul <apacin@igalia.com>

# Test Battery

# Note: you have to play with a big TreeView (the same for all
# instances of the same application).

# Note: to avoid differences in load times, this script opens and 
# closes once each tested aplication just before testing it.

if test $# -ne 1
then
  echo -n 'tests_valgrind.sh <before|after|master|master-wc> \n'; exit
fi

# We need 4 branches to test the commit changes.
# First called 'listen-to-all', just before the commit.
# Second called 'listen-to-registered', just after the commit.
# Third is the master branch.
# Fourth is the master branch without the tested commit changes.
BEFORE='listen-to-all'
AFTER='listen-to-registered'
MASTER='master'
MASTERWC='master-wc'

# Gnome checkout path
CPATH="$HOME/checkout/gnome"

# Change the directory to can work with git.
cd $CPATH/at-spi2-atk

# Check the existence of the previous 2 branches.
# In other case, it creates them.
COMMIT='d0f7dd49eebedc8c3993a116411f5a8320965968'

# if ! test `git branch | grep $BEFORE | cut -c 3-`
# then
#   git checkout $MASTER
#   git branch $BEFORE "$COMMIT^"
# fi
# 
# if ! test `git branch | grep $AFTER | cut -c 3-`
# then
#   git checkout $MASTER
#   git branch $AFTER $COMMIT
# fi
# 
# if ! test `git branch | grep $MASTERWC | cut -c 3-`
# then
#   git checkout $MASTER
#   git branch $MASTERWC
#   git checkout $MASTERWC
#   git revert $COMMIT
#   git checkout $MASTER
# fi

# $1 = parameter indicating if the tests mast run over the existent code 
# before/after the commit or over the master/master-wc branch.
case $1 in
  before)
    if test `git branch | grep \* | cut -c 3-` != $BEFORE
    then
      git checkout $BEFORE
      git clean -fdx
      jhbuild buildone at-spi2-atk
    fi;;
  after)
    if test `git branch | grep \* | cut -c 3-` != $AFTER
    then
      git checkout $AFTER
      git clean -fdx
      jhbuild buildone at-spi2-atk
    fi;;
  master)
    if test `git branch | grep \* | cut -c 3-` != $MASTER
    then
      git checkout $MASTER
      git clean -fdx
      jhbuild buildone at-spi2-atk
    fi;;
  master-wc)
    if test `git branch | grep \* | cut -c 3-` != $MASTERWC
    then
      git checkout $MASTERWC
      git clean -fdx
      jhbuild buildone at-spi2-atk
    fi;;
  *)
    echo -n 'tests_valgrind.sh <before|after|master|master-wc> \n'; exit;;
esac

# Return to the previous path to continue working.
cd -

# Sleep time.
STIME=100
# Wait time.
WTIME=10

# Path with a long list of elements.
URI='/usr/bin'

nautilus $URI &
sleep $WTIME
killall nautilus
sleep $WTIME
echo -n '\n ******** Nautilus Tests ******** \n\n'
sleep $WTIME
sh valgrind.sh false false out_"$1"_valgrind_nautilus_false_false_"$STIME" "nautilus $URI" $STIME
# sh valgrind.sh true false out_"$1"_valgrind_nautilus_true_false_"$STIME" "nautilus $URI" $STIME

# rhythmbox &
# sleep $WTIME
# killall rhythmbox
# sleep $WTIME
# echo -n '\n ******** Rhythmbox Tests ******** \n\n'
# sleep $WTIME
# sh valgrind.sh false false out_"$1"_valgrind_rhythmbox_false_false_"$STIME" rhythmbox $STIME
# sh valgrind.sh true false out_"$1"_valgrind_rhythmbox_true_false_"$STIME" rhythmbox $STIME
 
# Close automatically Orca instances is a hard job, so I have had to do this test at the finish.
# echo -n '\n ******** Mixed tests with Orca running ******** \n\n'
# sleep $WTIME
# sh valgrind.sh true true out_"$1"_valgrind_nautilus_true_true_"$STIME" "nautilus $URI" $STIME
# sh valgrind.sh true true out_"$1"_valgrind_rhythmbox_true_true_"$STIME" rhythmbox $STIME
